@@ -417,7 +417,7 @@ acx_ioctl_get_aplist(
 	}
 
 	cur = 0;
-	for (i = 0; i < VEC_SIZE(adev->sta_list); i++) {
+	for (i = 0; i < ARRAY_SIZE(adev->sta_list); i++) {
 		struct client *bss = &adev->sta_list[i];
 		if (!bss->used) continue;
 		MAC_COPY(address[cur].sa_data, bss->bssid);
@@ -622,7 +622,7 @@ acx_ioctl_get_scan(
 	}
 #endif
 
-	for (i = 0; i < VEC_SIZE(adev->sta_list); i++) {
+	for (i = 0; i < ARRAY_SIZE(adev->sta_list); i++) {
 		struct client *bss = &adev->sta_list[i];
 		if (!bss->used) continue;
 		ptr = acx_s_scan_add_station(adev, ptr,
@@ -733,7 +733,7 @@ static void
 acx_l_update_client_rates(acx_device_t *adev, u16 rate)
 {
 	int i;
-	for (i = 0; i < VEC_SIZE(adev->sta_list); i++) {
+	for (i = 0; i < ARRAY_SIZE(adev->sta_list); i++) {
 		client_t *clt = &adev->sta_list[i];
 		if (!clt->used)	continue;
 		clt->rate_cfg = (clt->rate_cap & rate);
@@ -809,7 +809,7 @@ acx_ioctl_set_rate(
 		vwrq->value, vwrq->fixed, vwrq->disabled, vwrq->flags);
 
 	if ((0 == vwrq->fixed) || (1 == vwrq->fixed)) {
-		int i = VEC_SIZE(acx111_rate_tbl)-1;
+		int i = ARRAY_SIZE(acx111_rate_tbl)-1;
 		if (vwrq->value == -1)
 			/* "iwconfig rate auto" --> choose highest */
 			vwrq->value = IS_ACX100(adev) ?	22000000 : 54000000;
@@ -1732,7 +1732,7 @@ acx_ioctl_set_short_preamble(
 	case 1:
 		/* short, kick incapable peers */
 		adev->preamble_cur = 1;
-		for (i = 0; i < VEC_SIZE(adev->sta_list); i++) {
+		for (i = 0; i < ARRAY_SIZE(adev->sta_list); i++) {
 			client_t *clt = &adev->sta_list[i];
 			if (!clt->used) continue;
 			if (!(clt->cap_info & WF_MGMT_CAP_SHORT)) {
@@ -1749,7 +1749,7 @@ acx_ioctl_set_short_preamble(
 		break;
 	case 2: /* auto. short only if all peers are short-capable */
 		adev->preamble_cur = 1;
-		for (i = 0; i < VEC_SIZE(adev->sta_list); i++) {
+		for (i = 0; i < ARRAY_SIZE(adev->sta_list); i++) {
 			client_t *clt = &adev->sta_list[i];
 			if (!clt->used) continue;
 			if (!(clt->cap_info & WF_MGMT_CAP_SHORT)) {
@@ -2732,9 +2732,9 @@ static const struct iw_priv_args acx_ioctl_private_args[] = {
 
 const struct iw_handler_def acx_ioctl_handler_def =
 {
-	.num_standard = VEC_SIZE(acx_ioctl_handler),
-	.num_private = VEC_SIZE(acx_ioctl_private_handler),
-	.num_private_args = VEC_SIZE(acx_ioctl_private_args),
+	.num_standard = ARRAY_SIZE(acx_ioctl_handler),
+	.num_private = ARRAY_SIZE(acx_ioctl_private_handler),
+	.num_private_args = ARRAY_SIZE(acx_ioctl_private_args),
 	.standard = (iw_handler *) acx_ioctl_handler,
 	.private = (iw_handler *) acx_ioctl_private_handler,
 	.private_args = (struct iw_priv_args *) acx_ioctl_private_args,
