@@ -859,7 +859,9 @@ acxusb_e_probe(struct usb_interface *intf, const struct usb_device_id *devID)
 	ndev->watchdog_timeo = 4 * HZ;
 #endif
 	ndev->change_mtu = &acx_e_change_mtu;
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,6,24)) && defined(SET_MODULE_OWNER)
 	SET_MODULE_OWNER(ndev);
+#endif
 
 	/* Setup private driver context */
 
@@ -1448,7 +1450,7 @@ acxusb_i_complete_rx(struct urb *urb, struct pt_regs *regs)
 			stat->rate, stat->ack_failures, stat->rts_failures,
 			stat->rts_ok);
 
-			if (adev->rate_auto && client_no < VEC_SIZE(adev->sta_list)) {
+			if (adev->rate_auto && client_no < ARRAY_SIZE(adev->sta_list)) {
 				client_t *clt = &adev->sta_list[client_no];
 				u16 cur = stat->hostdata >> 16;
 
@@ -1844,7 +1846,7 @@ dump_device(struct usb_device *usbdev)
 			printk("%d:%d ", i, usbdev->ep_in[i]->desc.wMaxPacketSize);
 	printk("\n");
 	printk("  ep_out wMaxPacketSize: ");
-	for (i = 0; i < VEC_SIZE(usbdev->ep_out); ++i)
+	for (i = 0; i < ARRAY_SIZE(usbdev->ep_out); ++i)
 		if (usbdev->ep_out[i] != NULL)
 			printk("%d:%d ", i, usbdev->ep_out[i]->desc.wMaxPacketSize);
 	printk("\n");
